==> soprano_2.0.0.orig.tar.gz: soprano-2.0.0.orig/server/serverconnection.h <==
/* 
 * This file is part of Soprano Project.
 *
 * Copyright (C) 2007 Sebastian Trueg <trueg@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _SOPRANO_SERVER_CONNECTION_H_
#define _SOPRANO_SERVER_CONNECTION_H_

#include <QtCore/QThread>
#include <QtNetwork/QTcpSocket>


namespace Soprano {

    class Backend;

    namespace Server {

        class ServerCore;

        class ServerConnection : public QThread
        {
            Q_OBJECT

        public:
            /**
             * Create a new ServerConnection.
             *
             * \param core The ServerCore that maintains all Models.
             * \param socket The connection socket.
             */
            ServerConnection( ServerCore* core );
            ~ServerConnection();

            void close();

            void start( QIODevice* socket );

        protected:
            void run();

        private:
            class Private;
            Private* const d;
        };
    }
}

#endif

==> soprano_2.4.2+dfsg.1.orig.tar.gz: soprano-2.4.2/server/serverconnection.h <==
/*
 * This file is part of Soprano Project.
 *
 * Copyright (C) 2007-2009 Sebastian Trueg <trueg@kde.org>
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public License
 * along with this library; see the file COPYING.LIB.  If not, write to
 * the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
 * Boston, MA 02110-1301, USA.
 */

#ifndef _SOPRANO_SERVER_CONNECTION_H_
#define _SOPRANO_SERVER_CONNECTION_H_

#include <QtCore/QObject>
#include <QtCore/QThread>

class QIODevice;

namespace Soprano {

    class Backend;
    namespace Util {
        class AsyncResult;
    }

    namespace Server {

        class ServerCore;
        class ModelPool;

        class ServerConnection : public QThread
        {
            Q_OBJECT

        public:
            /**
             * Create a new ServerConnection.
             *
             * \param core The ServerCore that maintains all Models.
             * \param socket The connection socket.
             */
            ServerConnection( ModelPool* pool, ServerCore* core );
            ~ServerConnection();

            void close();

            void start( QIODevice* socket );

        protected:
            void run();

        private:
            class Private;
            Private* const d;

            Q_PRIVATE_SLOT( d, void _s_readNextCommand() )
        };
    }
}

#endif
